#!/usr/bin/env python

__RCSID__ = "$Id$"

# generic imports
from multiprocessing import Pool
import signal
import os

# DIRAC imports
from DIRAC import gLogger
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Core.Base.Script import Script

Script.setUsageMessage(
    """
Download files from a list of lfns with N parallel process
Usage:
   cta-prod-get-file [options] <ascii file with lfn list> --NbProcess=8
"""
)

Script.registerSwitch("", "NbProcess=", "    number of process")
switches, args = Script.parseCommandLine(ignoreErrors=True)
# Import of DIRAC API must comes after parseCommandLine
from DIRAC.Interfaces.API.Dirac import Dirac

TEMPDIR = ".incomplete"


def sigint_handler(signum, frame):
    """
    Raise KeyboardInterrupt on SIGINT (CTRL + C)
    This should be the default, but apparently Dirac changes it.
    """
    raise KeyboardInterrupt()


def getfile(lfn):
    dirac = Dirac()
    gLogger.notice("Start downloading file", lfn)
    res = dirac.getFile(lfn, destDir=TEMPDIR)

    if not res["OK"]:
        gLogger.error("Error downloading file", lfn)
        return res["Message"]

    name = os.path.basename(lfn)
    os.rename(os.path.join(".incomplete", name), name)
    gLogger.notice("Successfully downloaded file", lfn)


@Script()
def main():
    if len(args) == 1:
        infile = args[0]
    else:
        Script.showHelp()

    nbProcess = 8
    for switch in switches:
        if switch[0] == "NbProcess":
            nbProcess = int(switch[1])

    # put files currently downloading in a subdirectory
    # to know which files have already finished
    if not os.path.exists(TEMPDIR):
        os.makedirs(TEMPDIR)

    infileList = read_inputs_from_file(infile)
    # see https://stackoverflow.com/a/35134329/3838691
    # ignore sigint before creating the pool,
    # so child processes inherit the setting, we will terminate them
    # if the master process catches sigint
    signal.signal(signal.SIGINT, signal.SIG_IGN)
    p = Pool(nbProcess)
    # add the original handler back
    signal.signal(signal.SIGINT, sigint_handler)

    try:
        future = p.map_async(getfile, infileList)

        while not future.ready():
            future.wait(5)
    except (SystemExit, KeyboardInterrupt):
        gLogger.fatal("Received SIGINT, waiting for subprocesses to terminate")
        p.close()
        p.terminate()
    finally:
        p.close()
        p.join()
        if len(os.listdir(TEMPDIR)) == 0:
            os.rmdir(TEMPDIR)


if __name__ == "__main__":
    main()



"""
    Launcher script for a simple job example
"""

__RCSID__ = "$Id$"

from DIRAC.Core.Base import Script

Script.parseCommandLine()
from DIRAC.Interfaces.API.Job import Job
from DIRAC import gLogger
from DIRAC.Interfaces.API.Dirac import Dirac

dirac = Dirac()
job = Job()
job.setExecutable("echo", arguments="Hello world")
job.setName("testjob")
res = dirac.submitJob(job)
gLogger.notice("Submission Result:", res["Value"])



#!/usr/bin/env python
"""
Create a transformation to remove files (all replicas)

Usage:
cta-transformation-remove-files <lfn or ascii file with a list of lfns> <group size> <extra_tag>

Arguments:
<lfn or ascii file with a list of lfns>: files to be removed
<group size>: size of the transformation (default=1)
<extra_tag>: extra tag appended to the name of the transformation

Example:
cta-transformation-remove-files lfns.list 100 prod5b_data
"""

__RCSID__ = "$Id$"

import os

import DIRAC
from DIRAC import gLogger
from DIRAC.Core.Base.Script import Script
from DIRAC.TransformationSystem.Client.Transformation import Transformation
from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file


@Script()
def main():
    lfn_list = []
    Script.parseCommandLine(ignoreErrors=True)
    argss = Script.getPositionalArgs()
    if len(argss) != 3:
        Script.showHelp()

    if os.path.isfile(argss[0]):
        gLogger.notice("Reading lfns from input file:", argss[0])
        lfn_list = read_inputs_from_file(argss[0])
    else:
        lfn_list.append(argss[0])

    group_size = int(argss[1])
    extra_tag = argss[2]

    t = Transformation()
    tc = TransformationClient()
    trans_name = f"Removing_{extra_tag}"
    t.setTransformationName(trans_name)
    t.setType("Removal")
    t.setDescription("Removing file")
    t.setLongDescription("Removing file")
    t.setGroupSize(group_size)
    t.setPlugin("Standard")
    transBody = "Removal;RemoveFile"
    t.setBody(transBody)

    res = t.addTransformation()
    if not res["OK"]:
        gLogger.error(res["Message"])
        DIRAC.exit(-1)

    transID = t.getTransformationID()
    res = tc.addFilesToTransformation(transID["Value"], lfn_list)
    if not res["OK"]:
        gLogger.error(res["Message"])
        DIRAC.exit(-1)

    t.setAgentType("Automatic")
    t.setStatus("Active")

    DIRAC.exit()


#########################################################
if __name__ == "__main__":
    main()



#!/usr/bin/env python

__RCSID__ = "$Id$"

# generic imports
from multiprocessing import Pool

# DIRAC imports
from DIRAC import gLogger
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Core.Base.Script import Script

Script.setUsageMessage(
    """
Bulk removal of a list of replicas at a given SE from the catalog
Usage:
   cta-prod-unregister-replica <ascii file with lfn list> <SE>
"""
)

Script.parseCommandLine(ignoreErrors=True)
# Must comes after parseCommandLine
from DIRAC.Resources.Catalog.FileCatalog import FileCatalog

fc = FileCatalog()

args = Script.getPositionalArgs()
if len(args) > 1:
    infile = args[0]
    SE = args[1]
else:
    Script.showHelp()


def unregisterReplicas(lfn):
    res = fc.getReplicas(lfn)
    if res["OK"]:
        if lfn in res["Value"]["Failed"]:
            gLogger.error(res["Value"]["Failed"][lfn])
        else:
            pfn = res["Value"]["Successful"][lfn][SE]
            replicaDict = {lfn: {"PFN": pfn, "SE": SE}}
            res = fc.removeReplica(replicaDict)
            if not res["OK"]:
                gLogger.error(res["Message"])
    else:
        gLogger.error(res["Message"])


@Script()
def main():
    infileList = read_inputs_from_file(infile)
    p = Pool(10)
    p.map(unregisterReplicas, infileList)


if __name__ == "__main__":
    main()



# generic imports
import os
import glob
import json

# DIRAC imports
import DIRAC
#from DIRAC.Core.Base.Script import Script

# CTADIRAC imports
from CTADIRAC.Core.Utilities.tool_box import run_number_from_filename
from CTADIRAC.Core.Workflow.Modules.ProdDataManager import ProdDataManager
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file

#Script.parseCommandLine()
#argss = Script.getPositionalArgs()

DIRAC.initialize()  # Initialize configuration

def main():

    prod_dm = ProdDataManager()

    out_lfn = "/vo.cta.in2p3.fr/MC/PROD5b/LaPalma/gamma/ctapipe-merge/5883/Data/000xxx/gamma_20deg_0deg_run80___cta-prod5b-lapalma_desert-2158m-LaPalma-dark.merged.DL2.h5"
    in_lfn_list = [
    "/vo.cta.in2p3.fr/MC/PROD5b/LaPalma/gamma/ctapipe-process/5755/Data/000xxx/gamma_20deg_0deg_run912___cta-prod5b-lapalma_desert-2158m-LaPalma-dark.DL2.h5",
    "/vo.cta.in2p3.fr/MC/PROD5b/LaPalma/gamma/ctapipe-process/5755/Data/000xxx/gamma_20deg_0deg_run918___cta-prod5b-lapalma_desert-2158m-LaPalma-dark.DL2.h5"]

    map_lfn = {out_lfn : in_lfn_list}
    DIRAC.gLogger.notice("Mapping output/input")
    for key, value in map_lfn.items():
        DIRAC.gLogger.notice(
        f"{key} mapped to {value}"
        )
        DIRAC.gLogger.notice(f"Setting file status to PROCESSED {value}")
        res = prod_dm.setTransformationFileStatus(value, "PROCESSED")
        if not res["OK"]:
            DIRAC.gLogger.warn(f"Failed to set file status to PROCESSED {value}")
####################################################
if __name__ == "__main__":
    main()


""" Utility for building production tests
"""

__RCSID__ = "$Id$"

import json

from DIRAC.Core.Base.Script import Script

Script.parseCommandLine()

# from DIRAC
from DIRAC import gLogger
from DIRAC import S_OK
from DIRAC.ProductionSystem.Client.ProductionClient import ProductionClient
from DIRAC.ProductionSystem.Client.ProductionStep import ProductionStep
from DIRAC.DataManagementSystem.Client.DataManager import DataManager
from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
from DIRAC.Interfaces.API.Dirac import Dirac
from testJobDefinitions import create_workflow_body_step
from testJobDefinitions import create_workflow_body_step1
from testJobDefinitions import create_workflow_body_step2

dm = DataManager()
prod_client = ProductionClient()
prod_desc = prod_client.prodDescription
dirac = Dirac()

testDir = "/vo.cta.in2p3.fr/tests/prodsys"


def create_production_step(name, type, input_query=None, output_query=None):
    prod_step = ProductionStep()
    prod_step.Name = name
    prod_step.Type = type
    prod_step.Inputquery = input_query
    prod_step.Outputquery = output_query
    return prod_step


def set_md_in_dfc():
    md_field_dict = {
        "application": "VARCHAR(128)",
        "image_format": "VARCHAR(128)",
        "image_width": "int",
        "image_height": "int",
    }
    fc = FileCatalog()
    for md_field in md_field_dict.keys():
        md_field_type = md_field_dict[md_field]
        res = fc.addMetadataField(md_field, md_field_type)
        yield res


def clean_prod_sys_dir():
    gLogger.notice("Cleaning directory", testDir)
    res = dm.cleanLogicalDirectory(testDir)
    return res


# Create the first production step and add it to the Production
def create_prod_step1(output_se=None):
    outputquery = {
        "application": "mandelbrot",
        "image_format": "ascii",
        "image_width": 7680,
        "image_height": 200,
    }
    prod_step1 = create_production_step(
        "ImageProd", "MCSimulation", output_query=outputquery
    )
    if output_se:
        body = create_workflow_body_step1(output_se=output_se)
    else:
        body = create_workflow_body_step()
    prod_step1.Body = body
    res = prod_client.addProductionStep(prod_step1)
    return res, prod_step1


# Create the second production step and add it to the Production
def create_prod_step2(prod_step1, output_se):
    input_query = {
        "application": "mandelbrot",
        "image_format": "ascii",
        "image_width": 7680,
        "image_height": 200,
    }
    output_query = {
        "application": "mandelbrot",
        "image_format": "ascii",
        "image_width": 7680,
        "image_height": 1400,
    }
    prod_step2 = create_production_step(
        "MergeImage",
        "DataReprocessing",
        input_query=input_query,
        output_query=output_query,
    )

    body = create_workflow_body_step2(output_se)
    prod_step2.Body = body
    prod_step2.GroupSize = 7
    prod_step2.ParentStep = prod_step1
    res = prod_client.addProductionStep(prod_step2)
    return res, prod_step2


# Check if there is already an existing production SeqProd and delete it
def get_prod(prod_name):
    res = prod_client.getProduction(prod_name)
    return res


def set_prod_status(prod_name, prod_client=prod_client, status="Stopped"):
    res = prod_client.setProductionStatus(prod_name, status)
    return res


def delete_prod(prod_name, prod_client=prod_client):
    res = prod_client.deleteProduction(prod_name)
    return res


def clean_prod(prod_name):
    res = prod_client.getProduction(prod_name)
    if res["OK"]:
        if res["Value"]["ProductionName"] == prod_name:
            print(f"Clean existing production {prod_name}")
            res = set_prod_status(prod_name=prod_name)
            if not res["OK"]:
                print(f"Failed to stop production {prod_name}")
            else:
                print(f"Stop production {prod_name}")
            res = delete_prod(prod_name=prod_name)
            if not res["OK"]:
                print(f"Failed to delete production {prod_name}")
            else:
                print(f"Deleted existing production {prod_name}")
    else:
        print(f"Failed to get production {prod_name}: {res['Message']}")
        return S_OK(res)
    return res


# Create the production SeqProd
def create_prod(prod_name, prod_desc=prod_desc):
    res = prod_client.addProduction(prod_name, json.dumps(prod_desc))
    return res


# Start the production, i.e. instantiate the transformation steps
def start_prod(prod_name):
    res = prod_client.startProduction(prod_name)
    return res


def get_prod_transformations(prod_name):
    res = prod_client.getProductionTransformations(prod_name)
    trans_list = res["Value"]
    return trans_list


def extend_transformation(transfo, n_tasks=21):
    res = transfo.extend_transformation(n_tasks, printOutput=False)
    return res


def get_transformation_jobs_id(trans_id):
    job_group = str(str(trans_id).zfill(8))
    # Choose jobs no more than 30 days old
    # jobDate = toString(datetime.datetime.utcnow().date() - 30 * day)
    res = dirac.selectJobs(jobGroup=job_group)
    return res



#!/usr/bin/env python

__RCSID__ = "$Id$"

# generic imports
import os
from multiprocessing import Pool

# DIRAC imports
import DIRAC
from DIRAC import gLogger
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Core.Base.Script import Script
from DIRAC.Resources.Catalog.FileCatalog import FileCatalog

Script.setUsageMessage(
    """
Bulk get file size from a list of lfns
Usage:
   cta-prod-get-file-size [options] <ascii file with lfn list>
"""
)

Script.parseCommandLine(ignoreErrors=True)

fc = FileCatalog()


@Script()
def main():
    args = Script.getPositionalArgs()
    if len(args) > 0:
        infile = args[0]
    else:
        Script.showHelp()

    infileList = read_inputs_from_file(infile)
    p = Pool(1)
    p.map(getSize, infileList)


def getSize(lfn):
    res = fc.getFileSize(lfn)
    if not res["OK"]:
        gLogger.error("Failed to get size for lfn", lfn)
        return res["Message"]
    if lfn in res["Value"]["Successful"]:
        size_GB = res["Value"]["Successful"][lfn] / (1024 * 1024 * 1024)
        gLogger.notice(f"{os.path.basename(lfn)} {size_GB:.1f} GB")
    else:
        res = DIRAC.S_ERROR(f"Failed to get size for lfn {lfn}")
        gLogger.error(res["Message"])
        return res


if __name__ == "__main__":
    main()



""" Module to find, install and setup software packages
    J. Bregeon, L. Arrabito
    15/09/2019
"""

__RCSID__ = "$Id$"

# generic imports
import os
import glob
import shutil

# DIRAC imports
import DIRAC
from DIRAC.DataManagementSystem.Client.DataManager import DataManager

# from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
from CTADIRAC.Core.Utilities.tool_box import get_os_and_cpu_info


class SoftwareManager:
    """Manage software setup"""

    def __init__(self, soft_category):
        """Constructor"""
        self.CVMFS_DIR = "/cvmfs/sw.cta-observatory.org/software"
        self.LFN_ROOT = "/vo.cta.in2p3.fr/software"
        self.SOFT_CATEGORY_DICT = soft_category
        self.dm = DataManager()

    def _search_software(self, package, version, compiler):
        """Look for sotfware package"""
        # software package category
        category = self.SOFT_CATEGORY_DICT[package]
        # look for software on cvmfs
        package_dir = os.path.join(
            self.CVMFS_DIR, "centos7", compiler, category, package, version
        )
        if os.path.isdir(package_dir):
            DIRAC.gLogger.notice(
                f"Found package {package} version {version} at:\n{package_dir}"
            )
            return DIRAC.S_OK({"Source": "cvmfs", "Path": package_dir})
        else:
            DIRAC.gLogger.notice(f"{package_dir}\n not found on cvmfs")

        return DIRAC.S_ERROR(
            f"Could not find package {package} / {version} / {compiler}"
        )

    def find_software(self, package, version, compiler="gcc48_default"):
        """check if the software package is installed in any software area
        Keyword arguments:
        package -- package name as the directory name
        version -- software version as the directory name
        compiler -- compiler version and configuration
        """

        # get platform and cpu information
        try:
            platform, cpu_name, inst = get_os_and_cpu_info()
            DIRAC.gLogger.notice(f"Running {platform} on {cpu_name} ({inst})")
        except BaseException:
            inst = "noOpt"
            DIRAC.gLogger.notice("Could not determine platform and cpu information")

        req_inst = compiler.split("_")[1]
        if req_inst == "default":
            results = self._search_software(package, version, compiler)
            return results
        elif req_inst == "noOpt":
            results = self._search_software(package, version, compiler)
            return results
        elif req_inst == "sse4":
            if inst in ["sse4", "avx", "avx2"]:
                results = self._search_software(package, version, compiler)
                return results
            else:
                DIRAC.gLogger.warn(
                    "CPU has no sse4 instructions, running non optimized version"
                )
                match_compiler = compiler.replace(req_inst, "noOpt")
                results = self._search_software(package, version, match_compiler)
                return results
        elif req_inst == "avx":
            if inst in ["avx", "avx2"]:
                results = self._search_software(package, version, compiler)
                return results
            else:
                DIRAC.gLogger.warn(
                    "CPU has no avx instructions, running non optimized version"
                )
                match_compiler = compiler.replace(req_inst, "noOpt")
                results = self._search_software(package, version, match_compiler)
                return results
        elif req_inst == "avx2":
            if inst in ["avx2"]:
                results = self._search_software(package, version, compiler)
                return results
            else:
                DIRAC.gLogger.warn(
                    "CPU has no avx2 instructions, running non optimized version"
                )
                match_compiler = compiler.replace(req_inst, "noOpt")
                results = self._search_software(package, version, match_compiler)
                return results
        elif compiler == "gcc83_avx512":
            if inst in ["avx512"]:
                results = self._search_software(package, version, compiler)
                return results
            else:
                DIRAC.gLogger.warn(
                    "CPU has no avx512 instructions, running non optimized version"
                )
                match_compiler = compiler.replace(req_inst, "noOpt")
                results = self._search_software(package, version, match_compiler)
                return results
        elif req_inst == "matchcpu":
            match_compiler = compiler.replace(req_inst, inst)
            if match_compiler == "gcc48_avx512":
                DIRAC.gLogger.warn(f"{inst} not available for gcc48")
                DIRAC.gLogger.warn("Using gcc83 avx512 instead")
                match_compiler = "gcc83_avx512"
            results = self._search_software(package, version, match_compiler)
            return results
        else:
            DIRAC.S_ERROR(f"Unknown compiler specified: {compiler}")
        return DIRAC.S_ERROR(
            "Could not find package %s version %s / %s in any location"
            % (package, version, compiler)
        )

    def install_dirac_scripts(self, package_dir):
        """copy DIRAC scripts in the current directory"""
        dirac_scripts = glob.glob(os.path.join(package_dir, "dirac_*"))
        try:
            for one_file in dirac_scripts:
                shutil.copy2(one_file, ".")
            return DIRAC.S_OK()
        except shutil.Error as error:
            return DIRAC.S_ERROR(f"Failed to install DIRAC scripts:\n{error}")

    def dump_setup_script_path(self, package_dir, textfilename="setup_script_path.txt"):
        """dump the path to setupPackage.sh in a one line ascii file
        to be read and source by the following script
        """
        script_path = os.path.join(package_dir, "setupPackage.sh")
        open(textfilename, "w").writelines(script_path + "\n")
        return DIRAC.S_OK()



#!/usr/bin/env python
"""
  Simple terminal job monitoring
"""
__RCSID__ = "$Id$"

from DIRAC import gLogger
from DIRAC.Core.Base.Script import Script
from CTADIRAC.Core.Utilities import tool_box
from CTADIRAC.Core.Utilities.tool_box import highlight


@Script()
def main():
    """Select jobs based on conditions"""
    Script.registerSwitch("", "owner=", "the job owner")
    Script.registerSwitch("", "jobGroup=", "the job group")
    Script.registerSwitch("", "hours=", "Get status for jobs of the last n hours")
    Script.registerSwitch(
        "", "failed=", '1 or 0 : Save or not failed jobs in "failed.txt"'
    )
    switches, argss = Script.parseCommandLine(ignoreErrors=True)
    # defaults
    owner = "arrabito"
    job_group = ""
    n_hours = 24

    for switch in switches:
        if switch[0].lower() == "owner":
            owner = switch[1]
        elif switch[0].lower() == "jobgroup":
            job_group = switch[1]
        elif switch[0].lower() == "hours":
            n_hours = int(switch[1])

    # do the jobs via the 2 main methods
    jobs_list = tool_box.get_job_list(owner, job_group, n_hours)
    gLogger.notice(
        '%s jobs found for group "%s" and owner "%s" in the past %s hours\n'
        % (len(jobs_list), job_group, owner, n_hours)
    )

    # get status dictionary
    status_dict, sites_dict = tool_box.parse_jobs_list(jobs_list)

    # print out my favourite tables
    gLogger.notice("%16s\tWaiting\tRunning\tFailed\tStalled\tDone\tTotal" % "Site")
    for key, val in sites_dict.items():
        txt = "%16s\t%s\t%s\t%s\t%s\t%s\t%s" % (
            key.split("LCG.")[-1],
            val["Waiting"],
            val["Running"],
            val["Failed"],
            val["Stalled"],
            val["Done"],
            val["Total"],
        )
        if float(val["Done"]) > 0.0:
            # More than 10% crash, print bold red
            if float(val["Failed"]) / float(val["Done"]) > 0.1:
                txt = highlight(txt)
        gLogger.notice(txt)

    gLogger.notice(
        "%16s\t%s\t%s\t%s\t%s\t%s\t%s"
        % (
            "Total",
            status_dict["Waiting"],
            status_dict["Running"],
            status_dict["Failed"],
            status_dict["Stalled"],
            status_dict["Done"],
            status_dict["Total"],
        )
    )


if __name__ == "__main__":
    main()



#!/usr/bin/env python
""" Set meta data in bulk for a list of files.
Usage:
   cta-prod-set-metadata <ascii file with lfn list> <metadata name> <metadata value>
"""

__RCSID__ = "$Id$"

import DIRAC
from DIRAC import gLogger
from DIRAC.Core.Base.Script import Script
from CTADIRAC.Core.Utilities.tool_box import read_inputs_from_file
from DIRAC.Resources.Catalog.FileCatalogClient import FileCatalogClient


@Script()
def main():
    Script.parseCommandLine()
    argss = Script.getPositionalArgs()

    if len(argss) == 3:
        infile = argss[0]
        meta_key = argss[1]
        meta_value = argss[2]
    else:
        Script.showHelp()

    lfns = read_inputs_from_file(infile)
    metadata = {meta_key: meta_value}
    pathMetaDict = {}

    for lfn in lfns:
        pathMetaDict[lfn] = metadata

    fc = FileCatalogClient()
    result = fc.setMetadataBulk(pathMetaDict)

    if not result["OK"]:
        gLogger.error(result["Message"])
        DIRAC.exit(-1)
    else:
        DIRAC.gLogger.notice(
            f"Successfully set meta data {meta_key} for {len(lfns)} files"
        )
        DIRAC.exit(0)


####################################################
if __name__ == "__main__":
    main()



""" Utility for building transformation tests
"""

__RCSID__ = "$Id$"

# from DIRAC
from DIRAC.TransformationSystem.Client.Transformation import Transformation
from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
from testJobDefinitions import create_workflow_body_step

transClient = TransformationClient()


def get_trans(trans_name):
    res = transClient.getTransformation(trans_name)
    return res


def clean_trans(trans_name):
    res = transClient.stopTransformation(trans_name)
    if not res["OK"]:
        print(f"Failed to stop transformation {trans_name}")
    else:
        print(f"Stop transformation {trans_name}")
    res = transClient.deleteTransformation(trans_name)
    if not res["OK"]:
        print(f"Failed to delete transformation {trans_name}")
    else:
        print(f"Deleted existing transformation {trans_name}")
    return res


def create_mc_transformation(trans_name):
    # Standard parameters
    transformation = Transformation()
    transformation.setTransformationName(trans_name)
    transformation.setType("MCSimulation")
    transformation.setDescription("MC Test")
    transformation.setLongDescription("MC Simulation Test Transformation")
    outputquery = {
        "application": "mandelbrot",
        "image_format": "ascii",
        "image_width": 7680,
        "image_height": 200,
    }
    transformation.setoutputMetaQuery(outputquery)
    workflow_body = create_workflow_body_step()
    transformation.setBody(workflow_body)
    res = transformation.addTransformation()
    transformation.setStatus("Active")
    transformation.setAgentType("Automatic")
    return res, transformation


def extend_trans(trans_id, n_tasks):
    res = transClient.extendTransformation(trans_id, n_tasks)
    if not res["OK"]:
        print(f"Failed to extend transformation {trans_id}")
    else:
        print(f"Extended transformation {trans_id} with {n_tasks} tasks")
    return res


def check_trans_status(trans_name):
    res = transClient.getTransformationParameters(trans_name, "Status")
    if not res["OK"]:
        print(f"Failed to get the status of transformation {trans_name}")
    else:
        status = res["Value"]
        print(f"Status of transformation {trans_name}: {status}")
    return res
